@@ -28,6 +28,9 @@
 #include <QDir>
 #include <QDebug>
 
+#include <KPluginLoader>
+#include <KPluginMetaData>
+
 class EventPluginsModel : public QAbstractListModel
 {
     Q_OBJECT
@@ -38,7 +41,8 @@ public:
         m_roles = QAbstractListModel::roleNames();
         m_roles.insert(Qt::EditRole, QByteArrayLiteral("checked"));
         m_roles.insert(Qt::UserRole, QByteArrayLiteral("configUi"));
-    };
+        m_roles.insert(Qt::UserRole + 1, QByteArrayLiteral("pluginPath"));
+    }
 
     // make these two available to the manager
     void beginResetModel()
@@ -51,39 +55,44 @@ public:
         QAbstractListModel::endResetModel();
     }
 
-    virtual QHash<int, QByteArray> roleNames() const Q_DECL_OVERRIDE
+    QHash<int, QByteArray> roleNames() const override
     {
         return m_roles;
     }
 
-    Q_INVOKABLE int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE
+    Q_INVOKABLE int rowCount(const QModelIndex &parent = QModelIndex()) const override
     {
         Q_UNUSED(parent);
         return m_manager->m_availablePlugins.size();
     }
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (!index.isValid() && !m_manager) {
             return QVariant();
         }
 
-        const QString currentPlugin = m_manager->m_availablePlugins.keys().at(index.row());
-        const QJsonObject metadata = m_manager->m_availablePlugins.value(currentPlugin).value(QStringLiteral("MetaData")).toObject();
+        const auto it = m_manager->m_availablePlugins.cbegin() + index.row();
+        const QString currentPlugin = it.key();
+        const EventPluginsManager::PluginData metadata = it.value();
 
         switch (role) {
             case Qt::DisplayRole:
-                return metadata.value(QStringLiteral("Name"));
+                return metadata.name;
+            case Qt::ToolTipRole:
+                return metadata.desc;
             case Qt::DecorationRole:
-                return metadata.value(QStringLiteral("Icon"));
+                return metadata.icon;
             case Qt::UserRole:
             {
                 // The currentPlugin path contains the full path including
                 // the plugin filename, so it needs to be cut off from the last '/'
-                const QStringRef pathRef = currentPlugin.leftRef(currentPlugin.lastIndexOf('/'));
-                const QString qmlFilePath = metadata.value(QStringLiteral("ConfigUi")).toString();
-                return QString(pathRef % '/' % qmlFilePath);
+                const QStringRef pathRef = currentPlugin.leftRef(currentPlugin.lastIndexOf(QLatin1Char('/')));
+                const QString qmlFilePath = metadata.configUi;
+                return QString(pathRef % QLatin1Char('/') % qmlFilePath);
             }
+            case Qt::UserRole + 1:
+                return currentPlugin;
             case Qt::EditRole:
                 return m_manager->m_enabledPlugins.contains(currentPlugin);
         }
@@ -92,7 +101,7 @@ public:
 
     }
 
-    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) Q_DECL_OVERRIDE
+    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override
     {
         if (role != Qt::EditRole || !index.isValid()) {
             return false;
@@ -127,11 +136,23 @@ private:
 EventPluginsManager::EventPluginsManager(QObject *parent)
     : QObject(parent)
 {
-    // First of all get a list of available plugins
-    // and get their metadata. This alone is enough
-    // for the applet config to work
+    auto plugins = KPluginLoader::findPlugins(
+            QStringLiteral("plasmacalendarplugins"),
+            [](const KPluginMetaData &md) {
+                return md.serviceTypes().contains(QLatin1String("PlasmaCalendar/Plugin"));
+            });
+    for (const KPluginMetaData &plugin : qAsConst(plugins)) {
+        m_availablePlugins.insert(plugin.fileName(),
+                                  { plugin.name(),
+                                    plugin.description(),
+                                    plugin.iconName(),
+                                    plugin.value(QStringLiteral("X-KDE-PlasmaCalendar-ConfigUi"))
+                                  });
+    }
+
+    // Fallback for legacy pre-KPlugin plugins so we can still load them
     const QStringList paths = QCoreApplication::libraryPaths();
-    Q_FOREACH (const QString &libraryPath, paths) {
+    for (const QString &libraryPath : paths) {
         const QString path(libraryPath + QStringLiteral("/plasmacalendarplugins"));
         QDir dir(path);
 
@@ -139,20 +160,29 @@ EventPluginsManager::EventPluginsManager(QObject *parent)
             continue;
         }
 
-        QStringList entryList = dir.entryList(QDir::Files | QDir::NoDotAndDotDot);
+        const QStringList entryList = dir.entryList(QDir::Files | QDir::NoDotAndDotDot);
 
-        Q_FOREACH (const QString &fileName, entryList) {
+        for (const QString &fileName : entryList) {
             const QString absolutePath = dir.absoluteFilePath(fileName);
+            if (m_availablePlugins.contains(absolutePath)) {
+                continue;
+            }
+
             QPluginLoader loader(absolutePath);
             // Load only our own plugins
             if (loader.metaData().value(QStringLiteral("IID")) == QLatin1String("org.kde.CalendarEventsPlugin")) {
-                m_availablePlugins.insert(absolutePath, loader.metaData());
+                const auto md = loader.metaData().value(QStringLiteral("MetaData")).toObject();
+                m_availablePlugins.insert(absolutePath,
+                                          { md.value(QStringLiteral("Name")).toString(),
+                                            md.value(QStringLiteral("Description")).toString(),
+                                            md.value(QStringLiteral("Icon")).toString(),
+                                            md.value(QStringLiteral("ConfigUi")).toString()
+                                          });
             }
         }
     }
 
     m_model = new EventPluginsModel(this);
-    Q_EMIT pluginsChanged();
 }
 
 EventPluginsManager::~EventPluginsManager()
@@ -187,7 +217,7 @@ void EventPluginsManager::setEnabledPlugins(QStringList &pluginsList)
     }
 
     // Now load all the plugins left in pluginsList
-    Q_FOREACH (const QString &pluginPath, pluginsList) {
+    for (const QString &pluginPath : qAsConst(pluginsList)) {
         loadPlugin(pluginPath);
     }
 
