@@ -21,6 +21,7 @@
 #define PLASMA_SVG_P_H
 
 #include <QHash>
+#include <QPointer>
 #include <QSharedData>
 #include <QSvgRenderer>
 #include <QExplicitlySharedDataPointer>
@@ -80,7 +81,7 @@ public:
     void eraseRenderer();
 
     QRectF elementRect(const QString &elementId);
-    QRectF findAndCacheElementRect(const QString &elementId);
+    QRectF findAndCacheElementRect(const QString &elementId, const QString &cacheId);
     QMatrix matrixForElement(const QString &elementId);
 
     void checkColorHints();
@@ -96,13 +97,13 @@ public:
     void colorsChanged();
 
     static QHash<QString, SharedSvgRenderer::Ptr> s_renderers;
-    static QWeakPointer<Theme> s_systemColorsCache;
+    static QPointer<Theme> s_systemColorsCache;
     static qreal s_lastScaleFactor;
 
     Svg *q;
-    QWeakPointer<Theme> theme;
+    QPointer<Theme> theme;
     QHash<QString, QRectF> localRectCache;
-    QHash<QString, QSize> elementsWithSizeHints;
+    QMultiHash<QString, QSize> elementsWithSizeHints;
     SharedSvgRenderer::Ptr renderer;
     QString themePath;
     QString path;
